@@ -121,13 +121,10 @@ inline void free_temp_surfaces(struct Surface **surfaces) {
     while((*surfaces) -> del) {
         struct Surface *next = (*surfaces) -> next;
         free_surface(*surfaces);
-        *surfaces = next;
+        if (!(*surfaces = next)) // if all surfaces were temporary, return
+            return;
     }
 
-    // if all surfaces were temporary, return
-    if (*surfaces == nullptr)
-        return;
-
     // free the rest of the surfaces
     struct Surface *prev = *surfaces;
     struct Surface *next;
@@ -934,7 +931,6 @@ static PyObject *method_raycasting(RayCasterObject *self, PyObject *args, PyObje
     for (int i = thread_count - 1; i >= 0; --i)
         threads[i] = new thread(thread_worker);  // C++ threads 💀 (pthreads ? never heard of them.)
 
-
     for (Py_ssize_t dst_y = height; dst_y; --dst_y) {
 
         projection = vec3_add(projection, height_vector);
